from setuptools import setup

setup(name='lanzajoke',
        version='0.1',
        description='The funniest joke in the world',
        url='http://github.com/lanza/lanzajoke',
        author='Nathan Lanza',
        author_email='nathan@lanza.io',
        license='MIT',
        packages=['lanzajoke'],
        zip_safe=False)
